# Chatbots

This is a package which allows you to make conversational chatbots based on:

- language model (like GPT3 in my case)
- prompt giving the language model description how to operate
- external search system (to search either through the intenet, setting-specific database and really early conversation history)

You see code example in `dixie.py`

```
Case: Hey, Dix. Remind me, why we call you Flatline?
Dixie: Well, because I died and my brain was active only for few minutes. Then you scanned it and created an AI copy.
```

Well, it's wrong, but similar to description.